Class: Pathname

Inherits:
Object
  • Object
show all
Defined in:
lib/pathname.rb,
lib/pathname.rb,
lib/pathname.rb,
ext/pathname/pathname.c

Overview

  • FileUtils *

Constant Summary collapse

TO_PATH =

to_path is implemented so Pathname objects are usable with File.open, etc.

:to_path
SAME_PATHS =
if File::FNM_SYSCASE.nonzero?
  # Avoid #zero? here because #casecmp can return nil.
  proc {|a, b| a.casecmp(b) == 0}
else
  proc {|a, b| a == b}
end
SEPARATOR_LIST =
"#{Regexp.quote File::SEPARATOR}"
SEPARATOR_PAT =
/#{Regexp.quote File::SEPARATOR}/

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(arg) ⇒ Object

Create a Pathname object from the given String (or String-like object). If path contains a NULL character (\0), an ArgumentError is raised.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'ext/pathname/pathname.c', line 96

static VALUE
path_initialize(VALUE self, VALUE arg)
{
    VALUE str;
    if (RB_TYPE_P(arg, T_STRING)) {
        str = arg;
    }
    else {
        str = rb_check_funcall(arg, id_to_path, 0, NULL);
        if (str == Qundef)
            str = arg;
        StringValue(str);
    }
    if (memchr(RSTRING_PTR(str), '\0', RSTRING_LEN(str)))
        rb_raise(rb_eArgError, "pathname contains null byte");
    str = rb_obj_dup(str);

    set_strpath(self, str);
    return self;
}

Class Method Details

.getwdObject

Returns the current working directory as a Pathname.

Pathname.getwd

#=> #<Pathname:/home/zzak/projects/ruby>

See Dir.getwd.



1185
1186
1187
1188
1189
1190
1191
# File 'ext/pathname/pathname.c', line 1185

static VALUE
path_s_getwd(VALUE klass)
{
    VALUE str;
    str = rb_funcall(rb_cDir, id_getwd, 0);
    return rb_class_new_instance(1, &str, klass);
}

.glob(*args) ⇒ Object

Returns or yields Pathname objects.

Pathname.glob("lib/i*.rb")

#=> [#<Pathname:lib/ipaddr.rb>, #<Pathname:lib/irb.rb>]

See Dir.glob.



1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
# File 'ext/pathname/pathname.c', line 1105

static VALUE
path_s_glob(int argc, VALUE *argv, VALUE klass)
{
    VALUE args[3];
    int n;

    n = rb_scan_args(argc, argv, "12", &args[0], &args[1], &args[2]);
    if (rb_block_given_p()) {
        return rb_block_call_kw(rb_cDir, id_glob, n, args, s_glob_i, klass, RB_PASS_CALLED_KEYWORDS);
    }
    else {
        VALUE ary;
        long i;
        ary = rb_funcallv_kw(rb_cDir, id_glob, n, args, RB_PASS_CALLED_KEYWORDS);
        ary = rb_convert_type(ary, T_ARRAY, "Array", "to_ary");
        for (i = 0; i < RARRAY_LEN(ary); i++) {
            VALUE elt = RARRAY_AREF(ary, i);
            elt = rb_class_new_instance(1, &elt, klass);
            rb_ary_store(ary, i, elt);
        }
        return ary;
    }
}

.pwdObject

Returns the current working directory as a Pathname.

Pathname.getwd

#=> #<Pathname:/home/zzak/projects/ruby>

See Dir.getwd.



1185
1186
1187
1188
1189
1190
1191
# File 'ext/pathname/pathname.c', line 1185

static VALUE
path_s_getwd(VALUE klass)
{
    VALUE str;
    str = rb_funcall(rb_cDir, id_getwd, 0);
    return rb_class_new_instance(1, &str, klass);
}

Instance Method Details

#+(other) ⇒ Object Also known as: /

Appends a pathname fragment to self to produce a new Pathname object. Since other is considered as a path relative to self, if other is an absolute path, the new Pathname object is created from just other.

p1 = Pathname.new("/usr")      # Pathname:/usr
p2 = p1 + "bin/ruby"           # Pathname:/usr/bin/ruby
p3 = p1 + "/etc/passwd"        # Pathname:/etc/passwd

# / is aliased to +.
p4 = p1 / "bin/ruby"           # Pathname:/usr/bin/ruby
p5 = p1 / "/etc/passwd"        # Pathname:/etc/passwd

This method doesn’t access the file system; it is pure string manipulation.



354
355
356
357
# File 'lib/pathname.rb', line 354

def +(other)
  other = Pathname.new(other) unless Pathname === other
  Pathname.new(plus(@path, other.to_s))
end

#<=>(other) ⇒ Object

Provides a case-sensitive comparison operator for pathnames.

Pathname.new(‘/usr’) <=> Pathname.new(‘/usr/bin’)

#=> -1

Pathname.new(‘/usr/bin’) <=> Pathname.new(‘/usr/bin’)

#=> 0

Pathname.new(‘/usr/bin’) <=> Pathname.new(‘/USR/BIN’)

#=> 1

It will return -1, 0 or 1 depending on the value of the left argument relative to the right argument. Or it will return nil if the arguments are not comparable.



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'ext/pathname/pathname.c', line 186

static VALUE
path_cmp(VALUE self, VALUE other)
{
    VALUE s1, s2;
    char *p1, *p2;
    char *e1, *e2;
    if (!rb_obj_is_kind_of(other, rb_cPathname))
        return Qnil;
    s1 = get_strpath(self);
    s2 = get_strpath(other);
    p1 = RSTRING_PTR(s1);
    p2 = RSTRING_PTR(s2);
    e1 = p1 + RSTRING_LEN(s1);
    e2 = p2 + RSTRING_LEN(s2);
    while (p1 < e1 && p2 < e2) {
        int c1, c2;
        c1 = (unsigned char)*p1++;
        c2 = (unsigned char)*p2++;
        if (c1 == '/') c1 = '\0';
        if (c2 == '/') c2 = '\0';
        if (c1 != c2) {
            if (c1 < c2)
                return INT2FIX(-1);
            else
                return INT2FIX(1);
        }
    }
    if (p1 < e1)
        return INT2FIX(1);
    if (p2 < e2)
        return INT2FIX(-1);
    return INT2FIX(0);
}

#==(other) ⇒ Object

Compare this pathname with other. The comparison is string-based. Be aware that two different paths (foo.txt and ./foo.txt) can refer to the same file.



164
165
166
167
168
169
170
# File 'ext/pathname/pathname.c', line 164

static VALUE
path_eq(VALUE self, VALUE other)
{
    if (!rb_obj_is_kind_of(other, rb_cPathname))
        return Qfalse;
    return rb_str_equal(get_strpath(self), get_strpath(other));
}

#===(other) ⇒ Object

Compare this pathname with other. The comparison is string-based. Be aware that two different paths (foo.txt and ./foo.txt) can refer to the same file.



164
165
166
167
168
169
170
# File 'ext/pathname/pathname.c', line 164

static VALUE
path_eq(VALUE self, VALUE other)
{
    if (!rb_obj_is_kind_of(other, rb_cPathname))
        return Qfalse;
    return rb_str_equal(get_strpath(self), get_strpath(other));
}

#absolute?Boolean

Predicate method for testing whether a path is absolute.

It returns true if the pathname begins with a slash.

p = Pathname.new('/im/sure')
p.absolute?
    #=> true

p = Pathname.new('not/so/sure')
p.absolute?
    #=> false


231
232
233
# File 'lib/pathname.rb', line 231

def absolute?
  ABSOLUTE_PATH.match? @path
end

#ascend {|_self| ... } ⇒ Object

Iterates over and yields a new Pathname object for each element in the given path in ascending order.

Pathname.new('/path/to/some/file.rb').ascend {|v| p v}
   #<Pathname:/path/to/some/file.rb>
   #<Pathname:/path/to/some>
   #<Pathname:/path/to>
   #<Pathname:/path>
   #<Pathname:/>

Pathname.new('path/to/some/file.rb').ascend {|v| p v}
   #<Pathname:path/to/some/file.rb>
   #<Pathname:path/to/some>
   #<Pathname:path/to>
   #<Pathname:path>

Returns an Enumerator if no block was given.

enum = Pathname.new("/usr/bin/ruby").ascend
  # ... do stuff ...
enum.each { |e| ... }
  # yields Pathnames /usr/bin/ruby, /usr/bin, /usr, and /.

It doesn’t access the filesystem.

Yields:

  • (_self)

Yield Parameters:

  • _self (Pathname)

    the object that the method was called on



328
329
330
331
332
333
334
335
336
337
# File 'lib/pathname.rb', line 328

def ascend
  return to_enum(__method__) unless block_given?
  path = @path
  yield self
  while r = chop_basename(path)
    path, = r
    break if path.empty?
    yield self.class.new(del_trailing_separator(path))
  end
end

#-Object

Returns the last access time for the file.

See File.atime.



502
503
504
505
506
# File 'ext/pathname/pathname.c', line 502

static VALUE
path_atime(VALUE self)
{
    return rb_funcall(rb_cFile, id_atime, 1, get_strpath(self));
}

#basename(*args) ⇒ Object

Returns the last component of the path.

See File.basename.



786
787
788
789
790
791
792
793
794
795
796
# File 'ext/pathname/pathname.c', line 786

static VALUE
path_basename(int argc, VALUE *argv, VALUE self)
{
    VALUE str = get_strpath(self);
    VALUE fext;
    if (rb_scan_args(argc, argv, "01", &fext) == 0)
        str = rb_funcall(rb_cFile, id_basename, 1, str);
    else
        str = rb_funcall(rb_cFile, id_basename, 2, str, fext);
    return rb_class_new_instance(1, &str, rb_obj_class(self));
}

#binread([length [, offset]]) ⇒ String

Returns all the bytes from the file, or the first N if specified.

See File.binread.



401
402
403
404
405
406
407
408
409
410
# File 'ext/pathname/pathname.c', line 401

static VALUE
path_binread(int argc, VALUE *argv, VALUE self)
{
    VALUE args[3];
    int n;

    args[0] = get_strpath(self);
    n = rb_scan_args(argc, argv, "02", &args[1], &args[2]);
    return rb_funcallv(rb_cFile, id_binread, 1+n, args);
}

#binwrite(string, [offset]) ⇒ Fixnum #binwrite(string, [offset], open_args) ⇒ Fixnum

Writes contents to the file, opening it in binary mode.

See File.binwrite.



443
444
445
446
447
448
449
450
451
452
# File 'ext/pathname/pathname.c', line 443

static VALUE
path_binwrite(int argc, VALUE *argv, VALUE self)
{
    VALUE args[4];
    int n;

    args[0] = get_strpath(self);
    n = rb_scan_args(argc, argv, "03", &args[1], &args[2], &args[3]);
    return rb_funcallv_kw(rb_cFile, id_binwrite, 1+n, args, RB_PASS_CALLED_KEYWORDS);
}

#-Object

Returns the birth time for the file. If the platform doesn’t have birthtime, raises NotImplementedError.

See File.birthtime.



518
519
520
521
522
# File 'ext/pathname/pathname.c', line 518

static VALUE
path_birthtime(VALUE self)
{
    return rb_funcall(rb_cFile, id_birthtime, 1, get_strpath(self));
}

#blockdev?Boolean

See FileTest.blockdev?.



862
863
864
865
866
# File 'ext/pathname/pathname.c', line 862

static VALUE
path_blockdev_p(VALUE self)
{
    return rb_funcall(rb_mFileTest, id_blockdev_p, 1, get_strpath(self));
}

#chardev?Boolean

See FileTest.chardev?.



871
872
873
874
875
# File 'ext/pathname/pathname.c', line 871

static VALUE
path_chardev_p(VALUE self)
{
    return rb_funcall(rb_mFileTest, id_chardev_p, 1, get_strpath(self));
}

#children(with_directory = true) ⇒ Object

Returns the children of the directory (files and subdirectories, not recursive) as an array of Pathname objects.

By default, the returned pathnames will have enough information to access the files. If you set with_directory to false, then the returned pathnames will contain the filename only.

For example:

pn = Pathname("/usr/lib/ruby/1.8")
pn.children
    # -> [ Pathname:/usr/lib/ruby/1.8/English.rb,
           Pathname:/usr/lib/ruby/1.8/Env.rb,
           Pathname:/usr/lib/ruby/1.8/abbrev.rb, ... ]
pn.children(false)
    # -> [ Pathname:English.rb, Pathname:Env.rb, Pathname:abbrev.rb, ... ]

Note that the results never contain the entries . and .. in the directory because they are not children.



447
448
449
450
451
452
453
454
455
456
457
458
459
# File 'lib/pathname.rb', line 447

def children(with_directory=true)
  with_directory = false if @path == '.'
  result = []
  Dir.foreach(@path) {|e|
    next if e == '.' || e == '..'
    if with_directory
      result << self.class.new(File.join(@path, e))
    else
      result << self.class.new(e)
    end
  }
  result
end

#chmod(mode_int) ⇒ Object

Changes file permissions.

See File.chmod.



564
565
566
567
568
# File 'ext/pathname/pathname.c', line 564

static VALUE
path_chmod(VALUE self, VALUE mode)
{
    return rb_funcall(rb_cFile, id_chmod, 2, mode, get_strpath(self));
}

#chown(owner_int, group_int) ⇒ Object

Change owner and group of the file.

See File.chown.



592
593
594
595
596
# File 'ext/pathname/pathname.c', line 592

static VALUE
path_chown(VALUE self, VALUE owner, VALUE group)
{
    return rb_funcall(rb_cFile, id_chown, 3, owner, group, get_strpath(self));
}

#cleanpath(consider_symlink = false) ⇒ Object

Returns clean pathname of self with consecutive slashes and useless dots removed. The filesystem is not accessed.

If consider_symlink is true, then a more conservative algorithm is used to avoid breaking symbolic linkages. This may retain more .. entries than absolutely necessary, but without accessing the filesystem, this can’t be avoided.

See Pathname#realpath.



92
93
94
95
96
97
98
# File 'lib/pathname.rb', line 92

def cleanpath(consider_symlink=false)
  if consider_symlink
    cleanpath_conservative
  else
    cleanpath_aggressive
  end
end

#-Object

Returns the last change time, using directory information, not the file itself.

See File.ctime.



536
537
538
539
540
# File 'ext/pathname/pathname.c', line 536

static VALUE
path_ctime(VALUE self)
{
    return rb_funcall(rb_cFile, id_ctime, 1, get_strpath(self));
}

#deleteObject

Removes a file or directory, using File.unlink if self is a file, or Dir.unlink as necessary.



1313
1314
1315
1316
1317
1318
1319
# File 'ext/pathname/pathname.c', line 1313

static VALUE
path_unlink(VALUE self)
{
    VALUE eENOTDIR = rb_const_get_at(rb_mErrno, id_ENOTDIR);
    VALUE str = get_strpath(self);
    return rb_rescue2(unlink_body, str, unlink_rescue, str, eENOTDIR, (VALUE)0);
}

#descendObject

Iterates over and yields a new Pathname object for each element in the given path in descending order.

Pathname.new('/path/to/some/file.rb').descend {|v| p v}
   #<Pathname:/>
   #<Pathname:/path>
   #<Pathname:/path/to>
   #<Pathname:/path/to/some>
   #<Pathname:/path/to/some/file.rb>

Pathname.new('path/to/some/file.rb').descend {|v| p v}
   #<Pathname:path>
   #<Pathname:path/to>
   #<Pathname:path/to/some>
   #<Pathname:path/to/some/file.rb>

Returns an Enumerator if no block was given.

enum = Pathname.new("/usr/bin/ruby").descend
  # ... do stuff ...
enum.each { |e| ... }
  # yields Pathnames /, /usr, /usr/bin, and /usr/bin/ruby.

It doesn’t access the filesystem.



295
296
297
298
299
300
301
# File 'lib/pathname.rb', line 295

def descend
  return to_enum(__method__) unless block_given?
  vs = []
  ascend {|v| vs << v }
  vs.reverse_each {|v| yield v }
  nil
end

#directory?Boolean

See FileTest.directory?.



916
917
918
919
920
# File 'ext/pathname/pathname.c', line 916

static VALUE
path_directory_p(VALUE self)
{
    return rb_funcall(rb_mFileTest, id_directory_p, 1, get_strpath(self));
}

#dirnameObject

Returns all but the last component of the path.

See File.dirname.



803
804
805
806
807
808
809
# File 'ext/pathname/pathname.c', line 803

static VALUE
path_dirname(VALUE self)
{
    VALUE str = get_strpath(self);
    str = rb_funcall(rb_cFile, id_dirname, 1, str);
    return rb_class_new_instance(1, &str, rb_obj_class(self));
}

#each_child(with_directory = true, &b) ⇒ Object

Iterates over the children of the directory (files and subdirectories, not recursive).

It yields Pathname object for each child.

By default, the yielded pathnames will have enough information to access the files.

If you set with_directory to false, then the returned pathnames will contain the filename only.

Pathname("/usr/local").each_child {|f| p f }
#=> #<Pathname:/usr/local/share>
#   #<Pathname:/usr/local/bin>
#   #<Pathname:/usr/local/games>
#   #<Pathname:/usr/local/lib>
#   #<Pathname:/usr/local/include>
#   #<Pathname:/usr/local/sbin>
#   #<Pathname:/usr/local/src>
#   #<Pathname:/usr/local/man>

Pathname("/usr/local").each_child(false) {|f| p f }
#=> #<Pathname:share>
#   #<Pathname:bin>
#   #<Pathname:games>
#   #<Pathname:lib>
#   #<Pathname:include>
#   #<Pathname:sbin>
#   #<Pathname:src>
#   #<Pathname:man>

Note that the results never contain the entries . and .. in the directory because they are not children.

See Pathname#children



497
498
499
# File 'lib/pathname.rb', line 497

def each_child(with_directory=true, &b)
  children(with_directory).each(&b)
end

#each_entryObject

Iterates over the entries (files and subdirectories) in the directory, yielding a Pathname object for each entry.



1287
1288
1289
1290
1291
1292
1293
1294
1295
# File 'ext/pathname/pathname.c', line 1287

static VALUE
path_each_entry(VALUE self)
{
    VALUE args[1];
    RETURN_ENUMERATOR(self, 0, 0);

    args[0] = get_strpath(self);
    return rb_block_call(rb_cDir, id_foreach, 1, args, each_entry_i, rb_obj_class(self));
}

#each_filenameObject

Iterates over each component of the path.

Pathname.new("/usr/bin/ruby").each_filename {|filename| ... }
  # yields "usr", "bin", and "ruby".

Returns an Enumerator if no block was given.

enum = Pathname.new("/usr/bin/ruby").each_filename
  # ... do stuff ...
enum.each { |e| ... }
  # yields "usr", "bin", and "ruby".


263
264
265
266
267
268
# File 'lib/pathname.rb', line 263

def each_filename # :yield: filename
  return to_enum(__method__) unless block_given?
  _, names = split_names(@path)
  names.each {|filename| yield filename }
  nil
end

#each_line {|line| ... } ⇒ Object #each_line(sep = $/[, open_args]) {|line| ... } ⇒ nil #each_line(limit[, open_args]) {|line| ... } ⇒ nil #each_line(sep, limit[, open_args]) {|line| ... } ⇒ nil #each_line(...) ⇒ Object

Iterates over each line in the file and yields a String object for each.

Overloads:

  • #each_line {|line| ... } ⇒ Object

    Yields:

    • (line)
  • #each_line(sep = $/[, open_args]) {|line| ... } ⇒ nil

    Yields:

    • (line)
  • #each_line(limit[, open_args]) {|line| ... } ⇒ nil

    Yields:

    • (line)
  • #each_line(sep, limit[, open_args]) {|line| ... } ⇒ nil

    Yields:

    • (line)


355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
# File 'ext/pathname/pathname.c', line 355

static VALUE
path_each_line(int argc, VALUE *argv, VALUE self)
{
    VALUE args[4];
    int n;

    args[0] = get_strpath(self);
    n = rb_scan_args(argc, argv, "03", &args[1], &args[2], &args[3]);
    if (rb_block_given_p()) {
        return rb_block_call_kw(rb_cFile, id_foreach, 1+n, args, 0, 0, RB_PASS_CALLED_KEYWORDS);
    }
    else {
        return rb_funcallv_kw(rb_cFile, id_foreach, 1+n, args, RB_PASS_CALLED_KEYWORDS);
    }
}

#empty?Boolean

Tests the file is empty.

See Dir#empty? and FileTest.empty?.



1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
# File 'ext/pathname/pathname.c', line 1080

static VALUE
path_empty_p(VALUE self)
{

    VALUE path = get_strpath(self);
    if (RTEST(rb_funcall(rb_mFileTest, id_directory_p, 1, path)))
        return rb_funcall(rb_cDir, id_empty_p, 1, path);
    else
        return rb_funcall(rb_mFileTest, id_empty_p, 1, path);
}

#entriesObject

Return the entries (files and subdirectories) in the directory, each as a Pathname object.

The results contains just the names in the directory, without any trailing slashes or recursive look-up.

pp Pathname.new('/usr/local').entries
#=> [#<Pathname:share>,
#    #<Pathname:lib>,
#    #<Pathname:..>,
#    #<Pathname:include>,
#    #<Pathname:etc>,
#    #<Pathname:bin>,
#    #<Pathname:man>,
#    #<Pathname:games>,
#    #<Pathname:.>,
#    #<Pathname:sbin>,
#    #<Pathname:src>]

The result may contain the current directory #<Pathname:.> and the parent directory #<Pathname:..>.

If you don’t want . and .. and want directories, consider Pathname#children.



1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
# File 'ext/pathname/pathname.c', line 1219

static VALUE
path_entries(VALUE self)
{
    VALUE klass, str, ary;
    long i;
    klass = rb_obj_class(self);
    str = get_strpath(self);
    ary = rb_funcall(rb_cDir, id_entries, 1, str);
    ary = rb_convert_type(ary, T_ARRAY, "Array", "to_ary");
    for (i = 0; i < RARRAY_LEN(ary); i++) {
        VALUE elt = RARRAY_AREF(ary, i);
        elt = rb_class_new_instance(1, &elt, klass);
        rb_ary_store(ary, i, elt);
    }
    return ary;
}

#eql?(other) ⇒ Boolean

Compare this pathname with other. The comparison is string-based. Be aware that two different paths (foo.txt and ./foo.txt) can refer to the same file.



164
165
166
167
168
169
170
# File 'ext/pathname/pathname.c', line 164

static VALUE
path_eq(VALUE self, VALUE other)
{
    if (!rb_obj_is_kind_of(other, rb_cPathname))
        return Qfalse;
    return rb_str_equal(get_strpath(self), get_strpath(other));
}

#executable?Boolean

See FileTest.executable?.



880
881
882
883
884
# File 'ext/pathname/pathname.c', line 880

static VALUE
path_executable_p(VALUE self)
{
    return rb_funcall(rb_mFileTest, id_executable_p, 1, get_strpath(self));
}

#executable_real?Boolean

See FileTest.executable_real?.



889
890
891
892
893
# File 'ext/pathname/pathname.c', line 889

static VALUE
path_executable_real_p(VALUE self)
{
    return rb_funcall(rb_mFileTest, id_executable_real_p, 1, get_strpath(self));
}

#exist?Boolean

See FileTest.exist?.



898
899
900
901
902
# File 'ext/pathname/pathname.c', line 898

static VALUE
path_exist_p(VALUE self)
{
    return rb_funcall(rb_mFileTest, id_exist_p, 1, get_strpath(self));
}

#expand_path(*args) ⇒ Object

Returns the absolute path for the file.

See File.expand_path.



828
829
830
831
832
833
834
835
836
837
838
# File 'ext/pathname/pathname.c', line 828

static VALUE
path_expand_path(int argc, VALUE *argv, VALUE self)
{
    VALUE str = get_strpath(self);
    VALUE dname;
    if (rb_scan_args(argc, argv, "01", &dname) == 0)
        str = rb_funcall(rb_cFile, id_expand_path, 1, str);
    else
        str = rb_funcall(rb_cFile, id_expand_path, 2, str, dname);
    return rb_class_new_instance(1, &str, rb_obj_class(self));
}

#extnameObject

Returns the file’s extension.

See File.extname.



816
817
818
819
820
821
# File 'ext/pathname/pathname.c', line 816

static VALUE
path_extname(VALUE self)
{
    VALUE str = get_strpath(self);
    return rb_funcall(rb_cFile, id_extname, 1, str);
}

#file?Boolean

See FileTest.file?.



925
926
927
928
929
# File 'ext/pathname/pathname.c', line 925

static VALUE
path_file_p(VALUE self)
{
    return rb_funcall(rb_mFileTest, id_file_p, 1, get_strpath(self));
}

#find(ignore_error: true) ⇒ Object

Iterates over the directory tree in a depth first manner, yielding a Pathname for each file under “this” directory.

Returns an Enumerator if no block is given.

Since it is implemented by the standard library module Find, Find.prune can be used to control the traversal.

If self is ., yielded pathnames begin with a filename in the current directory, not ./.

See Find.find



569
570
571
572
573
574
575
576
577
# File 'lib/pathname.rb', line 569

def find(ignore_error: true) # :yield: pathname
  return to_enum(__method__, ignore_error: ignore_error) unless block_given?
  require 'find'
  if @path == '.'
    Find.find(@path, ignore_error: ignore_error) {|f| yield self.class.new(f.sub(%r{\A\./}, '')) }
  else
    Find.find(@path, ignore_error: ignore_error) {|f| yield self.class.new(f) }
  end
end

#fnmatch(pattern, [flags]) ⇒ Boolean #fnmatch?(pattern, [flags]) ⇒ Boolean

Return true if the receiver matches the given pattern.

See File.fnmatch.



621
622
623
624
625
626
627
628
629
630
# File 'ext/pathname/pathname.c', line 621

static VALUE
path_fnmatch(int argc, VALUE *argv, VALUE self)
{
    VALUE str = get_strpath(self);
    VALUE pattern, flags;
    if (rb_scan_args(argc, argv, "11", &pattern, &flags) == 1)
        return rb_funcall(rb_cFile, id_fnmatch, 2, pattern, str);
    else
        return rb_funcall(rb_cFile, id_fnmatch, 3, pattern, str, flags);
}

#fnmatch(pattern, [flags]) ⇒ Boolean #fnmatch?(pattern, [flags]) ⇒ Boolean

Return true if the receiver matches the given pattern.

See File.fnmatch.



621
622
623
624
625
626
627
628
629
630
# File 'ext/pathname/pathname.c', line 621

static VALUE
path_fnmatch(int argc, VALUE *argv, VALUE self)
{
    VALUE str = get_strpath(self);
    VALUE pattern, flags;
    if (rb_scan_args(argc, argv, "11", &pattern, &flags) == 1)
        return rb_funcall(rb_cFile, id_fnmatch, 2, pattern, str);
    else
        return rb_funcall(rb_cFile, id_fnmatch, 3, pattern, str, flags);
}

#freezeObject

Freezes this Pathname.

See Object.freeze.



125
126
127
128
129
130
131
# File 'ext/pathname/pathname.c', line 125

static VALUE
path_freeze(VALUE self)
{
    rb_call_super(0, 0);
    rb_str_freeze(get_strpath(self));
    return self;
}

#-Object

Returns “type” of file (“file”, “directory”, etc).

See File.ftype.



640
641
642
643
644
# File 'ext/pathname/pathname.c', line 640

static VALUE
path_ftype(VALUE self)
{
    return rb_funcall(rb_cFile, id_ftype, 1, get_strpath(self));
}

#glob(*args) ⇒ Object

Returns or yields Pathname objects.

Pathname("ruby-2.4.2").glob("R*.md")
#=> [#<Pathname:ruby-2.4.2/README.md>, #<Pathname:ruby-2.4.2/README.ja.md>]

See Dir.glob. This method uses the base keyword argument of Dir.glob.



1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
# File 'ext/pathname/pathname.c', line 1145

static VALUE
path_glob(int argc, VALUE *argv, VALUE self)
{
    VALUE args[3];
    int n;

    n = rb_scan_args(argc, argv, "11", &args[0], &args[1]);
    if (n == 1)
      args[1] = INT2FIX(0);

    args[2] = rb_hash_new();
    rb_hash_aset(args[2], ID2SYM(id_base), get_strpath(self));

    n = 3;

    if (rb_block_given_p()) {
        return rb_block_call_kw(rb_cDir, id_glob, n, args, glob_i, self, RB_PASS_KEYWORDS);
    }
    else {
        VALUE ary;
        long i;
        ary = rb_funcallv_kw(rb_cDir, id_glob, n, args, RB_PASS_KEYWORDS);
        ary = rb_convert_type(ary, T_ARRAY, "Array", "to_ary");
        for (i = 0; i < RARRAY_LEN(ary); i++) {
            VALUE elt = RARRAY_AREF(ary, i);
            elt = rb_funcall(self, '+', 1, elt);
            rb_ary_store(ary, i, elt);
        }
        return ary;
    }
}

#grpowned?Boolean

See FileTest.grpowned?.



907
908
909
910
911
# File 'ext/pathname/pathname.c', line 907

static VALUE
path_grpowned_p(VALUE self)
{
    return rb_funcall(rb_mFileTest, id_grpowned_p, 1, get_strpath(self));
}

#hashObject

:nodoc:



225
226
227
228
229
# File 'ext/pathname/pathname.c', line 225

static VALUE
path_hash(VALUE self)
{
    return ST2FIX(rb_str_hash(get_strpath(self)));
}

#inspectObject

:nodoc:



247
248
249
250
251
252
253
# File 'ext/pathname/pathname.c', line 247

static VALUE
path_inspect(VALUE self)
{
    const char *c = rb_obj_classname(self);
    VALUE str = get_strpath(self);
    return rb_sprintf("#<%s:%"PRIsVALUE">", c, str);
}

#join(*args) ⇒ Object

Joins the given pathnames onto self to create a new Pathname object. This is effectively the same as using Pathname#+ to append self and all arguments sequentially.

path0 = Pathname.new("/usr")                # Pathname:/usr
path0 = path0.join("bin/ruby")              # Pathname:/usr/bin/ruby
    # is the same as
path1 = Pathname.new("/usr") + "bin/ruby"   # Pathname:/usr/bin/ruby
path0 == path1
    #=> true


414
415
416
417
418
419
420
421
422
423
424
425
# File 'lib/pathname.rb', line 414

def join(*args)
  return self if args.empty?
  result = args.pop
  result = Pathname.new(result) unless Pathname === result
  return result if result.absolute?
  args.reverse_each {|arg|
    arg = Pathname.new(arg) unless Pathname === arg
    result = arg + result
    return result if result.absolute?
  }
  self + result
end

#lchmod(mode_int) ⇒ Object

Same as Pathname.chmod, but does not follow symbolic links.

See File.lchmod.



578
579
580
581
582
# File 'ext/pathname/pathname.c', line 578

static VALUE
path_lchmod(VALUE self, VALUE mode)
{
    return rb_funcall(rb_cFile, id_lchmod, 2, mode, get_strpath(self));
}

#lchown(owner_int, group_int) ⇒ Object

Same as Pathname.chown, but does not follow symbolic links.

See File.lchown.



606
607
608
609
610
# File 'ext/pathname/pathname.c', line 606

static VALUE
path_lchown(VALUE self, VALUE owner, VALUE group)
{
    return rb_funcall(rb_cFile, id_lchown, 3, owner, group, get_strpath(self));
}

#lstatObject

See File.lstat.



726
727
728
729
730
# File 'ext/pathname/pathname.c', line 726

static VALUE
path_lstat(VALUE self)
{
    return rb_funcall(rb_cFile, id_lstat, 1, get_strpath(self));
}

#lutime(atime, mtime) ⇒ Object

Update the access and modification times of the file.

Same as Pathname#utime, but does not follow symbolic links.

See File.lutime.



775
776
777
778
779
# File 'ext/pathname/pathname.c', line 775

static VALUE
path_lutime(VALUE self, VALUE atime, VALUE mtime)
{
    return rb_funcall(rb_cFile, id_lutime, 3, atime, mtime, get_strpath(self));
}

Creates a hard link at pathname.

See File.link.



654
655
656
657
658
# File 'ext/pathname/pathname.c', line 654

static VALUE
path_make_link(VALUE self, VALUE old)
{
    return rb_funcall(rb_cFile, id_link, 2, old, get_strpath(self));
}

Creates a symbolic link.

See File.symlink.



740
741
742
743
744
# File 'ext/pathname/pathname.c', line 740

static VALUE
path_make_symlink(VALUE self, VALUE old)
{
    return rb_funcall(rb_cFile, id_symlink, 2, old, get_strpath(self));
}

#mkdir(*args) ⇒ Object

Create the referenced directory.

See Dir.mkdir.



1241
1242
1243
1244
1245
1246
1247
1248
1249
1250
# File 'ext/pathname/pathname.c', line 1241

static VALUE
path_mkdir(int argc, VALUE *argv, VALUE self)
{
    VALUE str = get_strpath(self);
    VALUE vmode;
    if (rb_scan_args(argc, argv, "01", &vmode) == 0)
        return rb_funcall(rb_cDir, id_mkdir, 1, str);
    else
        return rb_funcall(rb_cDir, id_mkdir, 2, str, vmode);
}

#mkpath(mode: nil) ⇒ Object

Creates a full path, including any intermediate directories that don’t yet exist.

See FileUtils.mkpath and FileUtils.mkdir_p



588
589
590
591
# File 'lib/pathname.rb', line 588

def mkpath(mode: nil)
  FileUtils.mkpath(@path, mode: mode)
  nil
end

#mountpoint?Boolean

Returns true if self points to a mountpoint.



199
200
201
202
203
204
205
206
207
# File 'lib/pathname.rb', line 199

def mountpoint?
  begin
    stat1 = self.lstat
    stat2 = self.parent.lstat
    stat1.dev != stat2.dev || stat1.ino == stat2.ino
  rescue Errno::ENOENT
    false
  end
end

#-Object

Returns the last modified time of the file.

See File.mtime.



550
551
552
553
554
# File 'ext/pathname/pathname.c', line 550

static VALUE
path_mtime(VALUE self)
{
    return rb_funcall(rb_cFile, id_mtime, 1, get_strpath(self));
}

#openObject #open(mode = "r"[, opt]) ⇒ File #open([mode [, perm]][, opt]) ⇒ File #open(mode = "r"[, opt]) {|file| ... } ⇒ Object #open([mode [, perm]][, opt]) {|file| ... } ⇒ Object

Opens the file for reading or writing.

See File.open.

Overloads:

  • #open(mode = "r"[, opt]) {|file| ... } ⇒ Object

    Yields:

    • (file)
  • #open([mode [, perm]][, opt]) {|file| ... } ⇒ Object

    Yields:

    • (file)


672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
# File 'ext/pathname/pathname.c', line 672

static VALUE
path_open(int argc, VALUE *argv, VALUE self)
{
    VALUE args[4];
    int n;

    args[0] = get_strpath(self);
    n = rb_scan_args(argc, argv, "03", &args[1], &args[2], &args[3]);
    if (rb_block_given_p()) {
        return rb_block_call_kw(rb_cFile, id_open, 1+n, args, 0, 0, RB_PASS_CALLED_KEYWORDS);
    }
    else {
        return rb_funcallv_kw(rb_cFile, id_open, 1+n, args, RB_PASS_CALLED_KEYWORDS);
    }
}

#opendirObject

Opens the referenced directory.

See Dir.open.



1268
1269
1270
1271
1272
1273
1274
1275
# File 'ext/pathname/pathname.c', line 1268

static VALUE
path_opendir(VALUE self)
{
    VALUE args[1];

    args[0] = get_strpath(self);
    return rb_block_call(rb_cDir, id_open, 1, args, 0, 0);
}

#owned?Boolean

See FileTest.owned?.



952
953
954
955
956
# File 'ext/pathname/pathname.c', line 952

static VALUE
path_owned_p(VALUE self)
{
    return rb_funcall(rb_mFileTest, id_owned_p, 1, get_strpath(self));
}

#parentObject

Returns the parent directory.

This is same as self + '..'.



194
195
196
# File 'lib/pathname.rb', line 194

def parent
  self + '..'
end

#pipe?Boolean

See FileTest.pipe?.



934
935
936
937
938
# File 'ext/pathname/pathname.c', line 934

static VALUE
path_pipe_p(VALUE self)
{
    return rb_funcall(rb_mFileTest, id_pipe_p, 1, get_strpath(self));
}

#read([length [, offset]]) ⇒ String #read([length [, offset]], open_args) ⇒ String

Returns all data from the file, or the first N bytes if specified.

See File.read.



381
382
383
384
385
386
387
388
389
390
# File 'ext/pathname/pathname.c', line 381

static VALUE
path_read(int argc, VALUE *argv, VALUE self)
{
    VALUE args[4];
    int n;

    args[0] = get_strpath(self);
    n = rb_scan_args(argc, argv, "03", &args[1], &args[2], &args[3]);
    return rb_funcallv_kw(rb_cFile, id_read, 1+n, args, RB_PASS_CALLED_KEYWORDS);
}

#readable?Boolean

See FileTest.readable?.



961
962
963
964
965
# File 'ext/pathname/pathname.c', line 961

static VALUE
path_readable_p(VALUE self)
{
    return rb_funcall(rb_mFileTest, id_readable_p, 1, get_strpath(self));
}

#readable_real?Boolean

See FileTest.readable_real?.



979
980
981
982
983
# File 'ext/pathname/pathname.c', line 979

static VALUE
path_readable_real_p(VALUE self)
{
    return rb_funcall(rb_mFileTest, id_readable_real_p, 1, get_strpath(self));
}

#readlines(sep = $/[, open_args]) ⇒ Array #readlines(limit[, open_args]) ⇒ Array #readlines(sep, limit[, open_args]) ⇒ Array

Returns all the lines from the file.

See File.readlines.



465
466
467
468
469
470
471
472
473
474
# File 'ext/pathname/pathname.c', line 465

static VALUE
path_readlines(int argc, VALUE *argv, VALUE self)
{
    VALUE args[4];
    int n;

    args[0] = get_strpath(self);
    n = rb_scan_args(argc, argv, "03", &args[1], &args[2], &args[3]);
    return rb_funcallv_kw(rb_cFile, id_readlines, 1+n, args, RB_PASS_CALLED_KEYWORDS);
}

Read symbolic link.

See File.readlink.



693
694
695
696
697
698
699
# File 'ext/pathname/pathname.c', line 693

static VALUE
path_readlink(VALUE self)
{
    VALUE str;
    str = rb_funcall(rb_cFile, id_readlink, 1, get_strpath(self));
    return rb_class_new_instance(1, &str, rb_obj_class(self));
}

#realdirpath(*args) ⇒ Object

Returns the real (absolute) pathname of self in the actual filesystem.

Does not contain symlinks or useless dots, .. and ..

The last component of the real pathname can be nonexistent.



336
337
338
339
340
341
342
343
# File 'ext/pathname/pathname.c', line 336

static VALUE
path_realdirpath(int argc, VALUE *argv, VALUE self)
{
    VALUE basedir, str;
    rb_scan_args(argc, argv, "01", &basedir);
    str = rb_funcall(rb_cFile, id_realdirpath, 2, get_strpath(self), basedir);
    return rb_class_new_instance(1, &str, rb_obj_class(self));
}

#realpath(*args) ⇒ Object

Returns the real (absolute) pathname for self in the actual filesystem.

Does not contain symlinks or useless dots, .. and ..

All components of the pathname must exist when this method is called.



320
321
322
323
324
325
326
327
# File 'ext/pathname/pathname.c', line 320

static VALUE
path_realpath(int argc, VALUE *argv, VALUE self)
{
    VALUE basedir, str;
    rb_scan_args(argc, argv, "01", &basedir);
    str = rb_funcall(rb_cFile, id_realpath, 2, get_strpath(self), basedir);
    return rb_class_new_instance(1, &str, rb_obj_class(self));
}

#relative?Boolean

The opposite of Pathname#absolute?

It returns false if the pathname begins with a slash.

p = Pathname.new('/im/sure')
p.relative?
    #=> false

p = Pathname.new('not/so/sure')
p.relative?
    #=> true


246
247
248
# File 'lib/pathname.rb', line 246

def relative?
  !absolute?
end

#relative_path_from(base_directory) ⇒ Object

Returns a relative path from the given base_directory to the receiver.

If self is absolute, then base_directory must be absolute too.

If self is relative, then base_directory must be relative too.

This method doesn’t access the filesystem. It assumes no symlinks.

ArgumentError is raised when it cannot find a relative path.

Note that this method does not handle situations where the case sensitivity of the filesystem in use differs from the operating system default.



515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
# File 'lib/pathname.rb', line 515

def relative_path_from(base_directory)
  base_directory = Pathname.new(base_directory) unless base_directory.is_a? Pathname
  dest_directory = self.cleanpath.to_s
  base_directory = base_directory.cleanpath.to_s
  dest_prefix = dest_directory
  dest_names = []
  while r = chop_basename(dest_prefix)
    dest_prefix, basename = r
    dest_names.unshift basename if basename != '.'
  end
  base_prefix = base_directory
  base_names = []
  while r = chop_basename(base_prefix)
    base_prefix, basename = r
    base_names.unshift basename if basename != '.'
  end
  unless SAME_PATHS[dest_prefix, base_prefix]
    raise ArgumentError, "different prefix: #{dest_prefix.inspect} and #{base_directory.inspect}"
  end
  while !dest_names.empty? &&
        !base_names.empty? &&
        SAME_PATHS[dest_names.first, base_names.first]
    dest_names.shift
    base_names.shift
  end
  if base_names.include? '..'
    raise ArgumentError, "base_directory has ..: #{base_directory.inspect}"
  end
  base_names.fill('..')
  relpath_names = base_names + dest_names
  if relpath_names.empty?
    Pathname.new('.')
  else
    Pathname.new(File.join(*relpath_names))
  end
end

#rename(to) ⇒ Object

Rename the file.

See File.rename.



706
707
708
709
710
# File 'ext/pathname/pathname.c', line 706

static VALUE
path_rename(VALUE self, VALUE to)
{
    return rb_funcall(rb_cFile, id_rename, 2, get_strpath(self), to);
}

#rmdirObject

Remove the referenced directory.

See Dir.rmdir.



1257
1258
1259
1260
1261
# File 'ext/pathname/pathname.c', line 1257

static VALUE
path_rmdir(VALUE self)
{
    return rb_funcall(rb_cDir, id_rmdir, 1, get_strpath(self));
}

#rmtree(noop: nil, verbose: nil, secure: nil) ⇒ Object

Recursively deletes a directory, including all directories beneath it.

See FileUtils.rm_rf



596
597
598
599
600
601
602
# File 'lib/pathname.rb', line 596

def rmtree(noop: nil, verbose: nil, secure: nil)
  # The name "rmtree" is borrowed from File::Path of Perl.
  # File::Path provides "mkpath" and "rmtree".
  require 'fileutils'
  FileUtils.rm_rf(@path, noop: noop, verbose: verbose, secure: secure)
  nil
end

#root?Boolean

Predicate method for root directories. Returns true if the pathname consists of consecutive slashes.

It doesn’t access the filesystem. So it may return false for some pathnames which points to roots such as /usr/...



216
217
218
# File 'lib/pathname.rb', line 216

def root?
  chop_basename(@path) == nil && /#{SEPARATOR_PAT}/o.match?(@path)
end

#setgid?Boolean

See FileTest.setgid?.



997
998
999
1000
1001
# File 'ext/pathname/pathname.c', line 997

static VALUE
path_setgid_p(VALUE self)
{
    return rb_funcall(rb_mFileTest, id_setgid_p, 1, get_strpath(self));
}

#setuid?Boolean

See FileTest.setuid?.



988
989
990
991
992
# File 'ext/pathname/pathname.c', line 988

static VALUE
path_setuid_p(VALUE self)
{
    return rb_funcall(rb_mFileTest, id_setuid_p, 1, get_strpath(self));
}

#sizeObject

See FileTest.size.



1006
1007
1008
1009
1010
# File 'ext/pathname/pathname.c', line 1006

static VALUE
path_size(VALUE self)
{
    return rb_funcall(rb_mFileTest, id_size, 1, get_strpath(self));
}

#size?Boolean

See FileTest.size?.



1015
1016
1017
1018
1019
# File 'ext/pathname/pathname.c', line 1015

static VALUE
path_size_p(VALUE self)
{
    return rb_funcall(rb_mFileTest, id_size_p, 1, get_strpath(self));
}

#socket?Boolean

See FileTest.socket?.



943
944
945
946
947
# File 'ext/pathname/pathname.c', line 943

static VALUE
path_socket_p(VALUE self)
{
    return rb_funcall(rb_mFileTest, id_socket_p, 1, get_strpath(self));
}

#splitObject

Returns the #dirname and the #basename in an Array.

See File.split.



845
846
847
848
849
850
851
852
853
854
855
856
857
# File 'ext/pathname/pathname.c', line 845

static VALUE
path_split(VALUE self)
{
    VALUE str = get_strpath(self);
    VALUE ary, dirname, basename;
    ary = rb_funcall(rb_cFile, id_split, 1, str);
    Check_Type(ary, T_ARRAY);
    dirname = rb_ary_entry(ary, 0);
    basename = rb_ary_entry(ary, 1);
    dirname = rb_class_new_instance(1, &dirname, rb_obj_class(self));
    basename = rb_class_new_instance(1, &basename, rb_obj_class(self));
    return rb_ary_new3(2, dirname, basename);
}

#statObject

Returns a File::Stat object.

See File.stat.



717
718
719
720
721
# File 'ext/pathname/pathname.c', line 717

static VALUE
path_stat(VALUE self)
{
    return rb_funcall(rb_cFile, id_stat, 1, get_strpath(self));
}

#sticky?Boolean

See FileTest.sticky?.



1024
1025
1026
1027
1028
# File 'ext/pathname/pathname.c', line 1024

static VALUE
path_sticky_p(VALUE self)
{
    return rb_funcall(rb_mFileTest, id_sticky_p, 1, get_strpath(self));
}

#sub(*args) ⇒ Object

Return a pathname which is substituted by String#sub.

path1 = Pathname.new(‘/usr/bin/perl’) path1.sub(‘perl’, ‘ruby’)

#=> #<Pathname:/usr/bin/ruby>


262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'ext/pathname/pathname.c', line 262

static VALUE
path_sub(int argc, VALUE *argv, VALUE self)
{
    VALUE str = get_strpath(self);

    if (rb_block_given_p()) {
        str = rb_block_call(str, id_sub, argc, argv, 0, 0);
    }
    else {
        str = rb_funcallv(str, id_sub, argc, argv);
    }
    return rb_class_new_instance(1, &str, rb_obj_class(self));
}

#sub_ext(repl) ⇒ Object

Return a pathname with repl added as a suffix to the basename.

If self has no extension part, repl is appended.

Pathname.new(‘/usr/bin/shutdown’).sub_ext(‘.rb’)

#=> #<Pathname:/usr/bin/shutdown.rb>


284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'ext/pathname/pathname.c', line 284

static VALUE
path_sub_ext(VALUE self, VALUE repl)
{
    VALUE str = get_strpath(self);
    VALUE str2;
    long extlen;
    const char *ext;
    const char *p;

    StringValue(repl);
    p = RSTRING_PTR(str);
    extlen = RSTRING_LEN(str);
    ext = ruby_enc_find_extname(p, &extlen, rb_enc_get(str));
    if (ext == NULL) {
        ext = p + RSTRING_LEN(str);
    }
    else if (extlen <= 1) {
        ext += extlen;
    }
    str2 = rb_str_subseq(str, 0, ext-p);
    rb_str_append(str2, repl);
    return rb_class_new_instance(1, &str2, rb_obj_class(self));
}

#symlink?Boolean

See FileTest.symlink?.



1033
1034
1035
1036
1037
# File 'ext/pathname/pathname.c', line 1033

static VALUE
path_symlink_p(VALUE self)
{
    return rb_funcall(rb_mFileTest, id_symlink_p, 1, get_strpath(self));
}

#sysopen([mode, [perm]]) ⇒ Fixnum

See IO.sysopen.



483
484
485
486
487
488
489
490
491
492
# File 'ext/pathname/pathname.c', line 483

static VALUE
path_sysopen(int argc, VALUE *argv, VALUE self)
{
    VALUE args[3];
    int n;

    args[0] = get_strpath(self);
    n = rb_scan_args(argc, argv, "02", &args[1], &args[2]);
    return rb_funcallv(rb_cIO, id_sysopen, 1+n, args);
}

#taintObject

Returns pathname. This method is deprecated and will be removed in Ruby 3.2.



139
140
141
142
143
144
# File 'ext/pathname/pathname.c', line 139

static VALUE
path_taint(VALUE self)
{
    rb_warn("Pathname#taint is deprecated and will be removed in Ruby 3.2.");
    return self;
}

#to_sString #to_pathString

Return the path as a String.

to_path is implemented so Pathname objects are usable with File.open, etc.



240
241
242
243
244
# File 'ext/pathname/pathname.c', line 240

static VALUE
path_to_s(VALUE self)
{
    return rb_obj_dup(get_strpath(self));
}

#to_sString #to_pathString

Return the path as a String.

to_path is implemented so Pathname objects are usable with File.open, etc.



240
241
242
243
244
# File 'ext/pathname/pathname.c', line 240

static VALUE
path_to_s(VALUE self)
{
    return rb_obj_dup(get_strpath(self));
}

#truncate(length) ⇒ Object

Truncates the file to length bytes.

See File.truncate.



751
752
753
754
755
# File 'ext/pathname/pathname.c', line 751

static VALUE
path_truncate(VALUE self, VALUE length)
{
    return rb_funcall(rb_cFile, id_truncate, 2, get_strpath(self), length);
}

Removes a file or directory, using File.unlink if self is a file, or Dir.unlink as necessary.



1313
1314
1315
1316
1317
1318
1319
# File 'ext/pathname/pathname.c', line 1313

static VALUE
path_unlink(VALUE self)
{
    VALUE eENOTDIR = rb_const_get_at(rb_mErrno, id_ENOTDIR);
    VALUE str = get_strpath(self);
    return rb_rescue2(unlink_body, str, unlink_rescue, str, eENOTDIR, (VALUE)0);
}

#untaintObject

Returns pathname. This method is deprecated and will be removed in Ruby 3.2.



152
153
154
155
156
157
# File 'ext/pathname/pathname.c', line 152

static VALUE
path_untaint(VALUE self)
{
    rb_warn("Pathname#untaint is deprecated and will be removed in Ruby 3.2.");
    return self;
}

#utime(atime, mtime) ⇒ Object

Update the access and modification times of the file.

See File.utime.



762
763
764
765
766
# File 'ext/pathname/pathname.c', line 762

static VALUE
path_utime(VALUE self, VALUE atime, VALUE mtime)
{
    return rb_funcall(rb_cFile, id_utime, 3, atime, mtime, get_strpath(self));
}

#world_readable?Boolean

See FileTest.world_readable?.



970
971
972
973
974
# File 'ext/pathname/pathname.c', line 970

static VALUE
path_world_readable_p(VALUE self)
{
    return rb_funcall(rb_mFileTest, id_world_readable_p, 1, get_strpath(self));
}

#world_writable?Boolean

See FileTest.world_writable?.



1051
1052
1053
1054
1055
# File 'ext/pathname/pathname.c', line 1051

static VALUE
path_world_writable_p(VALUE self)
{
    return rb_funcall(rb_mFileTest, id_world_writable_p, 1, get_strpath(self));
}

#writable?Boolean

See FileTest.writable?.



1042
1043
1044
1045
1046
# File 'ext/pathname/pathname.c', line 1042

static VALUE
path_writable_p(VALUE self)
{
    return rb_funcall(rb_mFileTest, id_writable_p, 1, get_strpath(self));
}

#writable_real?Boolean

See FileTest.writable_real?.



1060
1061
1062
1063
1064
# File 'ext/pathname/pathname.c', line 1060

static VALUE
path_writable_real_p(VALUE self)
{
    return rb_funcall(rb_mFileTest, id_writable_real_p, 1, get_strpath(self));
}

#write(string, [offset]) ⇒ Fixnum #write(string, [offset], open_args) ⇒ Fixnum

Writes contents to the file.

See File.write.



422
423
424
425
426
427
428
429
430
431
# File 'ext/pathname/pathname.c', line 422

static VALUE
path_write(int argc, VALUE *argv, VALUE self)
{
    VALUE args[4];
    int n;

    args[0] = get_strpath(self);
    n = rb_scan_args(argc, argv, "03", &args[1], &args[2], &args[3]);
    return rb_funcallv_kw(rb_cFile, id_write, 1+n, args, RB_PASS_CALLED_KEYWORDS);
}

#zero?Boolean

See FileTest.zero?.



1069
1070
1071
1072
1073
# File 'ext/pathname/pathname.c', line 1069

static VALUE
path_zero_p(VALUE self)
{
    return rb_funcall(rb_mFileTest, id_zero_p, 1, get_strpath(self));
}